# oct_vesselseg

This repository contains an implementation of computational geometry and domain randomization for synthesizing vascular structures and Optical Coherence Tomography (OCT) data. The project is inspired by the concepts and methodologies described in the [SynthSeg](https://github.com/BBillot/SynthSeg) project, adapted to the domain of vascular imaging.

## Table of Contents

- [Introduction](#introduction)
- [Getting Started](#getting-started)
  - [Requirements](#requirements)
  - [Installation](#installation)
- [Usage](#usage)
  - [Vessel Synthesis](#vessel-synthesis)
  - [OCT Image Synthesis](#image-synthesis)
  - [Training](#training)
  - [Inference](#inference)
- [Results](#results)
- [License](#license)
- [Acknowledgements](#acknowledgements)

## Introduction

This project focuses on generating synthetic datasets for training a 3D U-Net for the task of vasculature segmentation in OCT data. Using a cubic spline synthesis pipeline first established in [SynthSpline](https://github.com/balbasty/synthspline), and many data augmentation techniques from [Cornucopia](https://github.com/balbasty/cornucopia) this project employs domain-randomized synthesis to create structured labels, textures, and artifacts, enhancing the training of neural networks for vascular segmentation.

## Getting Started

### Requirements

- Python x.x.x
- PyTorch x.x.x
- Cornucopia x.x.x
- SynthSpline x.x.x
- NumPy x.x.x
- SciPy x.x.x
- nibabel x.x.x
- scikit-image x.x.x

### Installation
Clone the repository and install the required dependencies:
```bash
git clone https://github.com/EtienenChollet/oct_vesselseg.git
cd oct_vesselseg
mamba install requirements.txt 
```

## Usage

### Vessel Synthesis
Synthesize the vascular labels for training.
```bash
python3 vesselsynth.py --vessel_labels path/to/vessel_labels
```

### OCT Image Synthesis
Synthesize some examples of synthetic OCT images.
```bash
python3 imagesynth.py --vessel_labels path/to/vessel_labels
```

### Training
Train the model on the vessel labels and on-the-fly OCT image synthesis. You may want to train multiple models, which are denoted by the `--version` flag.
```bash
python3 train.py --vessel_labels path/to/vessel_labels --version 1 --epochs 100 --batch-size 1
```

### Inference
Run inference on compatable NIfTI data.
```bash
python3 inference.py --version 1 --in_fname path/to/raw_data --out_fname path/to/segmentation
```

## Results
Here we provide some examples of synthetic vasculature generated by this method:

## License
This project is licensed under the MIT License - see the LICENSE file for details.

## Acknowledgements
- [SynthSeg](https://github.com/BBillot/SynthSeg), [SynthSpline](https://github.com/balbasty/synthspline), and [Cornucopia](https://github.com/balbasty/cornucopia), for the inspiration and methodological foundation.
- Much of the computation resources required for this research was performed on computational hardware generously provided by the [Massachusetts Life Sciences Center](https://www.masslifesciences.com/).
